pub fn sample_weights_into(n: usize, out: &mut Vec<f64>)Expand description
Fill the provided buffer with recency weights without allocating. The buffer is cleared and filled to length n; capacity is retained so the second call with the same n does not allocate.